==> kubernetes-model-1.0.56-sources.jar: io/fabric8/openshift/api/model/DoneableRollingDeploymentStrategyParams.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.builder.Function;

public class DoneableRollingDeploymentStrategyParams extends RollingDeploymentStrategyParamsFluentImpl<DoneableRollingDeploymentStrategyParams> implements Doneable<RollingDeploymentStrategyParams>{

    private final RollingDeploymentStrategyParamsBuilder builder;
    private final Function<RollingDeploymentStrategyParams,RollingDeploymentStrategyParams> function;

    public DoneableRollingDeploymentStrategyParams(Function<RollingDeploymentStrategyParams,RollingDeploymentStrategyParams> function){
            super();this.builder=new RollingDeploymentStrategyParamsBuilder(this);this.function=function;
    }
    public DoneableRollingDeploymentStrategyParams(RollingDeploymentStrategyParams item,Function<RollingDeploymentStrategyParams,RollingDeploymentStrategyParams> function){
            super(item);this.builder=new RollingDeploymentStrategyParamsBuilder(this, item);this.function=function;
    }
    public DoneableRollingDeploymentStrategyParams(RollingDeploymentStrategyParams item){
            super(item);this.builder=new RollingDeploymentStrategyParamsBuilder(this, item);this.function=new Function<RollingDeploymentStrategyParams, RollingDeploymentStrategyParams>() {
    public RollingDeploymentStrategyParams apply(RollingDeploymentStrategyParams item) {
        return item;
    }
}
;
    }

    public RollingDeploymentStrategyParams done(){
             return function.apply(builder.build());
    }




}

==> kubernetes-model-4.3.0-sources.jar: io/fabric8/openshift/api/model/DoneableRollingDeploymentStrategyParams.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.model.Doneable;

public class DoneableRollingDeploymentStrategyParams extends RollingDeploymentStrategyParamsFluentImpl<DoneableRollingDeploymentStrategyParams> implements Doneable<RollingDeploymentStrategyParams>{

    private final RollingDeploymentStrategyParamsBuilder builder;
    private final io.fabric8.kubernetes.api.builder.Function<RollingDeploymentStrategyParams,RollingDeploymentStrategyParams> function;

    public DoneableRollingDeploymentStrategyParams(io.fabric8.kubernetes.api.builder.Function<RollingDeploymentStrategyParams,RollingDeploymentStrategyParams> function){
            super();this.builder=new RollingDeploymentStrategyParamsBuilder(this);this.function=function;
    }
    public DoneableRollingDeploymentStrategyParams(RollingDeploymentStrategyParams item,io.fabric8.kubernetes.api.builder.Function<RollingDeploymentStrategyParams,RollingDeploymentStrategyParams> function){
            super(item);this.builder=new RollingDeploymentStrategyParamsBuilder(this, item);this.function=function;
    }
    public DoneableRollingDeploymentStrategyParams(RollingDeploymentStrategyParams item){
            super(item);this.builder=new RollingDeploymentStrategyParamsBuilder(this, item);this.function=new Function<RollingDeploymentStrategyParams, RollingDeploymentStrategyParams>() {
    public RollingDeploymentStrategyParams apply(RollingDeploymentStrategyParams item) {
        return item;
    }
}
;
    }

    public RollingDeploymentStrategyParams done(){
             return function.apply(builder.build());
    }




}
